==> apache-plc4x-0.10.0-source-release.zip: apache-plc4x-0.10.0/plc4go/internal/knxnetip/SubscriptionHandle.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package knxnetip

import (
	spiModel "github.com/apache/plc4x/plc4go/spi/model"
	"time"
)

type SubscriptionHandle struct {
	*spiModel.DefaultPlcSubscriptionHandle
	fieldName string
	field     Field
	fieldType spiModel.SubscriptionType
	interval  time.Duration
}

func NewSubscriptionHandle(subscriber *Subscriber, fieldName string, field Field, fieldType spiModel.SubscriptionType, interval time.Duration) *SubscriptionHandle {
	s := &SubscriptionHandle{
		DefaultPlcSubscriptionHandle: spiModel.NewDefaultPlcSubscriptionHandle(subscriber),
		fieldName:                    fieldName,
		field:                        field,
		fieldType:                    fieldType,
		interval:                     interval,
	}
	s.DefaultPlcSubscriptionHandle = spiModel.NewDefaultPlcSubscriptionHandleWithHandleToRegister(subscriber, s)
	return s
}

==> apache-plc4x-0.11.0-source-release.zip: apache-plc4x-0.11.0/plc4go/internal/knxnetip/SubscriptionHandle.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package knxnetip

import (
	apiModel "github.com/apache/plc4x/plc4go/pkg/api/model"
	"time"

	spiModel "github.com/apache/plc4x/plc4go/spi/model"
)

type SubscriptionHandle struct {
	*spiModel.DefaultPlcSubscriptionHandle
	tagName  string
	tag      Tag
	tagType  apiModel.PlcSubscriptionType
	interval time.Duration
}

func NewSubscriptionHandle(subscriber *Subscriber, tagName string, tag Tag, tagType apiModel.PlcSubscriptionType, interval time.Duration) *SubscriptionHandle {
	handle := spiModel.NewDefaultPlcSubscriptionHandle(subscriber)
	s := &SubscriptionHandle{
		DefaultPlcSubscriptionHandle: handle.(*spiModel.DefaultPlcSubscriptionHandle),
		tagName:                      tagName,
		tag:                          tag,
		tagType:                      tagType,
		interval:                     interval,
	}
	s.DefaultPlcSubscriptionHandle = spiModel.NewDefaultPlcSubscriptionHandleWithHandleToRegister(subscriber, s)
	return s
}
